import 'antd/dist/antd.css';
import React, { useContext, useEffect } from 'react';

import { useUnauthRedirect } from '../../../hooks';
import { useRouter } from 'next/router';
import { Button, Typography } from 'antd';
import { faFileLines } from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { LoggedUserContext } from '../../../contexts/LoggedUserContext';
import { MainLayout } from '../../../layouts/MainLayout';
import AddDocumentModal from '../../../components/modals/AddDocumentModal';

function AdminDocumentPage() {
    const redirecting = useUnauthRedirect('/login');
    const { logout, role } = useContext(LoggedUserContext);
    const [visible, setVisible] = React.useState(false);
    const router = useRouter();

    useEffect(() => {
        if (!redirecting && role === 'ADMINISTRATOR') {
            // TODO load documents
        }
    }, [logout, redirecting, role, router]);

    const showModal = () => {
        setVisible(true);
    };

    const hideModal = () => {
        setVisible(false);
    };

    return redirecting || role !== 'ADMINISTRATOR' ? null : (
        <MainLayout>
            <Typography.Title level={2}>
                <FontAwesomeIcon icon={faFileLines} /> Dokumenty
            </Typography.Title>
            <Button type={'primary'} onClick={showModal}>
                Nahrát dokument
            </Button>
            {visible && <AddDocumentModal onCancel={hideModal} />}
        </MainLayout>
    );
}

export default AdminDocumentPage;
